Crate grelsolar

Crate grelsolar 

Modules

config
Application configuration loaded from environment variables.
container
Dependency injection container for grelsolar.
home_assistant
Home Assistant Integration Module The integration is done via HTTP JSON API.
services
Application Services module.
solarlog
Solar-Log Integration Module The integration is done via HTTP JSON API.